
# THIS FILE IS GENERATED FROM NUMPY SETUP.PY
#
# To compare versions robustly, use `numpy.lib.NumpyVersion`
short_version = '1.14.4'
version = '1.14.4'
full_version = '1.14.4'
git_revision = 'dcf9cf8bed3cb6b1c5cf6824937bba6c0a55ad9d'
release = True

if not release:
    version = full_version
